=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2011-04-17 09:57:36 +0000
+++ bzrlib/info.py	2011-09-30 12:58:20 +0000
@@ -221,7 +221,10 @@
     """Show missing revisions in working tree."""
     branch = working.branch
     basis = working.basis_tree()
-    branch_revno, branch_last_revision = branch.last_revision_info()
+    try:
+        branch_revno, branch_last_revision = branch.last_revision_info()
+    except errors.UnsupportedOperation:
+        return
     try:
         tree_last_id = working.get_parent_ids()[0]
     except IndexError:
@@ -268,7 +271,10 @@
 
 def _show_branch_stats(branch, verbose, outfile):
     """Show statistics about a branch."""
-    revno, head = branch.last_revision_info()
+    try:
+        revno, head = branch.last_revision_info()
+    except errors.UnsupportedOperation:
+        return {}
     outfile.write('\n')
     outfile.write('Branch history:\n')
     outfile.write('  %8d revision%s\n' % (revno, plural(revno)))

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2011-09-26 00:00:44 +0000
+++ bzrlib/tests/blackbox/test_info.py	2011-09-30 12:58:20 +0000
@@ -1345,3 +1345,33 @@
      stacked on: mainline
 """, out)
         self.assertEqual("", err)
+
+    def test_info_revinfo_optional(self):
+        tree = self.make_branch_and_tree('.')
+        def last_revision_info(self):
+            raise errors.UnsupportedOperation(last_revision_info, self)
+        self.overrideAttr(
+            branch.Branch, "last_revision_info", last_revision_info)
+        out, err = self.run_bzr('info -v .')
+        self.assertEqual(
+"""Standalone tree (format: 2a)
+Location:
+  branch root: .
+
+Format:
+       control: Meta directory format 1
+  working tree: Working tree format 6
+        branch: Branch format 7
+    repository: Repository format 2a - rich roots, group compression and chk inventories
+
+In the working tree:
+         0 unchanged
+         0 modified
+         0 added
+         0 removed
+         0 renamed
+         0 unknown
+         0 ignored
+         0 versioned subdirectories
+""", out)
+        self.assertEqual("", err)

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2011-09-30 09:17:59 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2011-09-30 12:58:20 +0000
@@ -45,6 +45,10 @@
 * Fixed a bug where ``bzr tags -r x..y`` loaded the branch history once for
   every revision in the range; it's now much faster. (Vincent Ladeuil, #857335)
 
+* ``bzr info -v`` can now be run against branches that don't support
+  ``last_revision_info``, in which case the branch information will simply
+  not be displayed. (Jelmer Vernooij)
+
 Bug Fixes
 *********
 

